@@ -469,7 +469,7 @@
                     (gnc:html-document-add-object!
                      document
                      (gnc:html-make-empty-data-warning 
-                      (_ "Average Balance"))))))
+                      (_ "Average Balance") (gnc:report-id report-obj))))))
           
           ;; make a table (optionally)
           (if show-table? 
@@ -494,7 +494,9 @@
         ;; if there are no accounts selected...
         (gnc:html-document-add-object! 
          document
-         (gnc:html-make-no-account-warning)))
+         (gnc:html-make-no-account-warning 
+	  report-title (gnc:report-id report-obj))))
+	  
     document))
 
 (gnc:define-report
